# Librería polinomio

<br>

Librería que te permite trabajar con polinomios como la clase VD.


<br>

## 💡 Prerequisitos

   [Python 3](https://www.python.org/downloads/release/python-370/)

<br>

## 📚 Ejemplo de uso

```
from polinomio import example

example()
```
<br>

## 🐸 Aloha!
<br>
